@@ -37,8 +37,8 @@ extern "C" {
 /* Some args are conceptually const, but SVR4 (and others?) get it wrong. */
 #define _C_const /* const */
 
-WINDOW * (newwin)(int lines, int cols, int sy, int sx);
-WINDOW * (subwin)(WINDOW *w, int lines, int cols, int sy, int sx);
+WINDOW * (newwin)(int, int, int, int);
+WINDOW * (subwin)(WINDOW *, int, int, int, int);
 WINDOW * (initscr)();
 int      (box) (WINDOW*, _G_chtype, _G_chtype);
 int      (delwin)(WINDOW*);
@@ -50,7 +50,7 @@ int      (overwrite)(WINDOW*, WINDOW*);
 int      (scroll)(WINDOW*);
 int      (touchwin)(WINDOW*);
 int      (waddch)(WINDOW*, _G_chtype);
-int      (waddstr)(WINDOW*, _C_const char*);
+int      (waddstr) _G_ARGS((WINDOW*, const char*));
 int      (wclear)(WINDOW*);
 int      (wclrtobot)(WINDOW*);
 int      (wclrtoeol)(WINDOW*);
@@ -68,16 +68,11 @@ int      (wstandout)(WINDOW*);
 
 // SVR4 rather inanely bundles the format-string parameter with the '...'.
 // This breaks VMS, and I don't want to penalize VMS for being right for once!
-#ifdef _VR3_COMPAT_CODE /* Magic cookie to recognize SVR4 */
-#define _CURSES_FORMAT_ARG /*const char* fmt, */
-#else
-#define _CURSES_FORMAT_ARG const char* fmt,
-#endif
 
-int      (wprintw)(WINDOW*, _CURSES_FORMAT_ARG ...);
-int      (mvwprintw)(WINDOW*, int y, int x, _CURSES_FORMAT_ARG ...);
-int      (wscanw)(WINDOW*, _CURSES_FORMAT_ARG ...);
-int      (mvwscanw)(WINDOW*, int, int, _CURSES_FORMAT_ARG ...);
+int      (wprintw)(WINDOW*, _G_CURSES_FORMAT_ARG ...);
+int      (mvwprintw)(WINDOW*, int y, int x, _G_CURSES_FORMAT_ARG ...);
+int      (wscanw)(WINDOW*, _G_CURSES_FORMAT_ARG ...);
+int      (mvwscanw)(WINDOW*, int, int, _G_CURSES_FORMAT_ARG ...);
 int      (endwin)();
 
 }
