@@ -28,7 +28,11 @@ extern struct group* getgrent();
 extern struct group* fgetgrent(FILE*);
 extern struct group* getgrgid(int);
 extern struct group* getgrnam(const char*);
+#ifdef __OSF1__
+extern int	     setgrent();
+#else
 extern void          setgrent();
+#endif
 extern void          endgrent();
 
 #endif
