@@ -64,6 +64,8 @@ int nint(double);
 #else
 extern "C" {
 
+#include <_G_config.h>
+
 double  acos(double);
 double  acosh(double);
 double  asin(double);
@@ -82,7 +84,7 @@ double  erfc(double);
 double  exp(double);
 double  expm1(double);
 double  fabs(double);
-double  finite(double);
+int finite(double);
 double  floor(double);
 double	fmod(double, double);
 double  frexp(double, int*);
@@ -106,7 +108,7 @@ double  logb(double);
 double  modf(double, double*);
 double  pow(double, double);
 double  rint(double);
-double  scalb(double, int);
+double  scalb _G_ARGS((double, int));
 double  sin(double);
 double  sinh(double);
 double  sqrt(double);
