@@ -55,7 +55,7 @@ int       setkey(const char*);
 int       srand(unsigned int);
 double    strtod(const char*, char**);
 long      strtol(const char*, char**, int);
-unsigned long stroul(const char**, int);
+unsigned long strtoul(const char*, char **, int);
 int       system(const char*);
 
 long      random(void);
