@@ -37,6 +37,9 @@ extern int       fstat _G_ARGS((int fd, struct stat *buf));
 #ifndef S_ISREG
 #define S_ISREG(mode) (((mode) & S_IFMT) == S_IFREG)
 #endif
+#if !defined(S_ISLNK) && defined(S_IFLNK)
+#define S_ISLNK(mode) (((mode) & S_IFMT) == S_IFLNK)
+#endif
 
 #endif
 }
