@@ -2295,107 +2295,98 @@ char* hex(const Integer& x, int width)
   return Itoa(x, 16, width);
 }
 
-istream& operator >> (istream& s, Integer& y)
+istream& operator >> (istream& stream, Integer& val)
 {
-#ifdef _OLD_STREAMS
-  if (!s.good())
-    return s;
-#else
-  if (!s.ipfx(0))
-  {
-    s.clear(ios::failbit|s.rdstate());
-    return s;
-  }
-#endif
-  s >> ws;
-  if (!s.good())
-  {
-    s.clear(ios::failbit|s.rdstate());
-    return s;
-  }
-  
-#ifdef _OLD_STREAMS
-  int know_base = 0;
+  if (!stream.ipfx0())
+    return 0;
+  int sign = ' ';
+  register streambuf* sb = stream.rdbuf();
   int base = 10;
-#else
-  int know_base = s.flags() & (ios::oct | ios::hex | ios::dec);
-  int base = (s.flags() & ios::oct) ? 8 : (s.flags() & ios::hex) ? 16 : 10;
-#endif
-
-  int got_one = 0;
-  char sgn = 0;
-  char ch;
-  y.rep = Icopy_zero(y.rep);
-
-  while (s.get(ch))
-  {
-    if (ch == '-')
+  int ndigits = 0;
+  register int ch = sb->sbumpc();
+  while (ch != EOF && isspace(ch))
+    ch = sb->sbumpc();
+  if (ch == '+' || ch == '-')
     {
-      if (sgn == 0)
-        sgn = '-';
-      else
-        break;
+      sign = ch;
+      ch = sb->sbumpc();
+      while (ch != EOF && isspace(ch))
+	ch = sb->sbumpc();
     }
-    else if (!know_base & !got_one && ch == '0')
-      base = 8, got_one = 1;
-    else if (!know_base & !got_one && base == 8 && (ch == 'X' || ch == 'x'))
-      base = 16;
-    else if (base == 8)
+  if (ch == EOF) goto eof_fail;
+  if (!(stream.flags() & ios::basefield))
     {
-      if (ch >= '0' && ch <= '7')
-      {
-        long digit = ch - '0';
-        y <<= 3;
-        y += digit;
-        got_one = 1;
-      }
-      else
-        break;
+      if (ch == '0')
+	{
+	  ch = sb->sbumpc();
+	  if (ch == EOF) { }
+	  else if (ch == 'x' || ch == 'X')
+	    {
+	      base = 16;
+	      ch = sb->sbumpc();
+	      if (ch == EOF) goto eof_fail;
+	    }
+	  else
+	    {
+	      sb->sputbackc(ch);
+	      base = 8;
+	      ch = '0';
+	    }
+	}
     }
-    else if (base == 16)
+  else if ((stream.flags() & ios::basefield) == ios::hex)
+    base = 16;
+  else if ((stream.flags() & ios::basefield) == ios::oct)
+    base = 8;
+
+  val.rep = Icopy_zero(val.rep);
+
+  for (;;)
     {
-      long digit;
+      if (ch == EOF)
+	break;
+      int digit;
       if (ch >= '0' && ch <= '9')
-        digit = ch - '0';
+	digit = ch - '0';
       else if (ch >= 'A' && ch <= 'F')
-        digit = ch - 'A' + 10;
+	digit = ch - 'A' + 10;
       else if (ch >= 'a' && ch <= 'f')
-        digit = ch - 'a' + 10;
+	digit = ch - 'a' + 10;
       else
-        digit = base;
-      if (digit < base)
-      {
-        y <<= 4;
-        y += digit;
-        got_one = 1;
-      }
-      else
-        break;
+	digit = 999;
+      if (digit >= base)
+	{
+	  sb->sputbackc(ch);
+	  if (ndigits == 0)
+	    goto fail;
+	  else
+	    goto done;
+	}
+      ndigits++;
+      switch (base)
+	{
+	case 8:
+	  val <<= 3;
+	  break;
+	case 16:
+	  val <<= 4;
+	  break;
+	default:
+	  val *= base;
+	  break;
+	}
+      val += digit;
+      ch = sb->sbumpc();
     }
-    else if (base == 10)
-    {
-      if (ch >= '0' && ch <= '9')
-      {
-        long digit = ch - '0';
-        y *= 10;
-        y += digit;
-        got_one = 1;
-      }
-      else
-        break;
-    }
-    else
-      abort(); // can't happen for now
-  }
-  if (s.good())
-    s.putback(ch);
-  if (!got_one)
-    s.clear(ios::failbit|s.rdstate());
-
-  if (sgn == '-')
-    y.negate();
-
-  return s;
+ fail:
+  stream.set(ios::failbit);
+ done:
+  if (sign == '-')
+    val.negate();
+  return stream;
+ eof_fail:
+  stream.set(ios::failbit|ios::eofbit);
+  return stream;
 }
 
 int Integer::OK() const
